/***************************************************************************

  c_alure.h

  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA 02110-1301, USA.

***************************************************************************/

#ifndef __C_ALURE_H
#define __C_ALURE_H

#include "main.h"

#ifndef __C_ALURE_C
extern GB_DESC AlureDesc[];
extern GB_DESC AlureStreamDesc[];
#endif

typedef
	struct {
		GB_BASE ob;
		alureStream *stream;
		GB_ARRAY buffers;
		char *addr;
		int len;
		volatile int stop;
	}
	CALURESTREAM;

#endif
